==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectPath.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectpath_h
#define objectpath_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_path {
  t_adms _adms;
  char* _value;
  int _value_isdefault : 1;
  GSList* _token;
  int _token_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_path_getuid (p_path mypath);
win32_interface gboolean adms_path_cmp (p_path mypath,p_path refpath);
win32_interface p_path adms_path_new_1 (char* myvalue);
#define adms_path_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_path_free(item)\
{\
  free(item->_value);\
  {GSList*l=item->_token;for(;l;l=l->next) free(l->data);}\
  g_slist_free(item->_token);\
  free(item);\
}
win32_interface p_adms adms_path_new_impl (p_adms arguments[]);
win32_interface p_path adms_path_impl (void* member);
#define adms_path(member) ((p_path) (member))
#define adms_path_new adms_path_new_1
#define adms_path_isdefault_value(path) (adms_path(path)->_value_isdefault)
#define adms_path_valueof_value(path) (adms_path(path)->_value)
#define adms_path_isdefault_token(path) (adms_path(path)->_token_isdefault)
#define adms_path_valueof_token(path) (adms_path(path)->_token)
#define adms_path_valueof_adms(path) ((p_adms)path)
#define adms_path_valueto_value(a,b) ((p_path)a)->_value=(b)
win32_interface void adms_path_valueto_value_impl (p_path mypath,char* _value);
#define adms_path_valueto_token(a,b) ((p_path)a)->_token=(b)
win32_interface void adms_path_valueto_token_impl (p_path mypath,GSList* _token);
win32_interface void adms_path_list_token_prepend_by_id (p_path mymypath,char* mytoken);
win32_interface void adms_path_list_token_prepend_once_or_ignore (p_path mymypath,char* mytoken);
#endif /* objectpath_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectPath.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectpath_h
#define objectpath_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_path {
  t_adms _adms;
  char* _value;
  int _value_isdefault : 1;
  p_slist _token;
  int _token_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_path_uid (p_path mypath);
win32_interface int adms_path_cmp (p_path mypath,p_path refpath);
win32_interface p_path adms_path_new(const char* myvalue);
win32_interface p_adms adms_path_new_impl (p_adms arguments[]);
#define adms_path(member) ((p_path) (member))
#define adms_path_isdefault_value(path) (adms_path(path)->_value_isdefault)
#define adms_path_valueof_value(path) (adms_path(path)->_value)
#define adms_path_isdefault_token(path) (adms_path(path)->_token_isdefault)
#define adms_path_valueof_token(path) (adms_path(path)->_token)
#define adms_path_valueof_adms(path) ((p_adms)path)
win32_interface inline void adms_path_valueto_value (p_path mypath,const char* _value);
win32_interface inline void adms_path_valueto_token (p_path mypath,p_slist _token);
win32_interface void adms_path_list_token_prepend_by_id (p_path mymypath,char* mytoken);
win32_interface void adms_path_list_token_prepend_once_or_ignore (p_path mymypath,char* mytoken);
win32_interface inline void adms_path_free(p_path mypath);
#endif /* objectpath_h */
